const express = require('express');
const { DynamoDBClient } = require('@aws-sdk/client-dynamodb');
const { DynamoDBDocumentClient, GetCommand, PutCommand } = require('@aws-sdk/lib-dynamodb');
const router = express.Router();

// Configuration DynamoDB
const dbClient = new DynamoDBClient({ region: 'us-east-1' });
const ddb = DynamoDBDocumentClient.from(dbClient);
const USERS_TABLE = 'Users';

// Page de connexion
router.get('/', (req, res) => {
    res.render('login', { error: null });
     });

// Gérer la connexion
router.post('/login', async (req, res) => {
    const { username } = req.body;

    if (!username) {
        return res.render('login', { error: 'Le champ username est requis' });
    }

    try {
        // Vérifier si l'utilisateur existe déjà
        const user = await ddb.send(new GetCommand({
            TableName: USERS_TABLE,
            Key: { username },
        }));

        if (!user.Item) {
            // Créer un nouvel utilisateur s'il n'existe pas
            await ddb.send(new PutCommand({
                TableName: USERS_TABLE,
                Item: { username },
            }));
        }

        // Rediriger vers la page d'accueil avec le nom d'utilisateur
        res.redirect(`/album/home?username=${username}`);
    } catch (err) {
        console.error(err);
        res.render('login', { error: 'Erreur lors de la connexion' });
    }
});

module.exports = router;
